/*
 * @Company: hugeInfo
 * @Author: ldh
 * @Date: 2022-07-08 09:33:05
 * @LastEditTime: 2022-11-03 10:17:36
 * @LastEditors: ldh
 * @Version: 1.0.0
 * @Description: 我的退回页面，TODO:暂不需要
 */
import React, { useEffect, useState } from 'react';
import { useNavigate, useLocation, useSearchParams } from 'react-router-dom';
import { Form, Typography } from 'antd';
import Page from '../../../components/Page';
import * as $$ from '../../../utils/utility';
import TableView from '../../../components/TableView';
import TableSearch from '../../../components/TableSearch';

// 获取我的退回数据
function getMyReturnDataApi(submitData) {
	return $$.ax.request({ url: 'caseTask/pageMyTask', type: 'get', data: submitData, service: 'mediate' });
}

const { Link } = Typography;

const MyReturn = () => {
	let location = useLocation();

	let navigate = useNavigate();

	const [searchParams] = useSearchParams();

	const [form] = Form.useForm();

	// 搜索
	const [search, setSearch] = useState({ page: 1, size: 10 });

	// 数据
	const [data, setData] = useState({ tableData: [] });

	// 查看，签收跳转
	function handleJump(record) {
		$$.setSessionStorage(location.pathname, {
			search: search,
			breadcrumbData: [{ title: '我的退回', url: location.pathname }, { title: '处理' }],
			title: record.caseNo,
			tabs: [{ label: '处理', key: 'caseHandle' }],
			tableActive: record.id,
			pageFrom: 'myReturn',
		});
		navigate(`/mediate/caseDetail?caseId=${record.caseId}&taskId=${record.id}&back=${location.pathname}`);
	}

	// 搜索 or 重置
	function handleSearch(type, data) {
		if (type === 'recovery') {
			// 案件详情返回时恢复跳转前查询
			let obj = Object.assign({}, data.search);
			if (obj.returnStart) obj.returnTime = [$$.myMoment(obj.returnStart), $$.myMoment(obj.returnEnd)];
			form.setFieldsValue(obj);
			getMyReturnData(obj, data.tableActive);
			return;
		}
		if (type === 'reset') {
			form.resetFields();
			getMyReturnData({ page: 1, size: 10 });
			return;
		}
		if (type === 'search') {
			let values = form.getFieldsValue();
			$$.changeTimeFormat(values, 'returnTime', 'returnStart', 'returnEnd');
			getMyReturnData({ ...search, ...values, page: 1 });
			return;
		}
		if (type === 'changePage') {
			getMyReturnData({ ...search, page: data[0], size: data[1] });
		}
	}

	// 获取数据
	async function getMyReturnData(submitData, tableActive) {
		global.setSpinning(true);
		const res = await getMyReturnDataApi({ ...submitData, pageType: '3' });
		global.setSpinning(false);
		if (res.type) {
			setData({
				total: res.data?.totalElements,
				tableData: res.data?.content,
				tableActive,
			});
			setSearch(submitData);
		}
	}

	// 初始化
	useEffect(() => {
		let returnRouteData = $$.getSessionStorage(location.pathname);
		if (searchParams.get('isBack') && !!returnRouteData) {
			handleSearch('recovery', returnRouteData);
		} else {
			handleSearch('reset');
		}
		if (!!returnRouteData) {
			$$.clearSessionStorage(location.pathname);
		}
	}, []);

	// 表头
	const columns = [
		{ title: '任务名称', dataIndex: 'taskNodeName' },
		{ title: '调解案号', dataIndex: 'caseNo' },
		{ title: '申请人', dataIndex: 'plaintiffs' },
		{ title: '被申请人', dataIndex: 'defendants' },
		{ title: '纠纷发生地', dataIndex: 'addr' },
		{ title: '纠纷类型', dataIndex: 'caseTypeName' },
		{ title: '申请渠道', dataIndex: 'canalName' },
		{ title: '退回人', dataIndex: 'returnUserName' },
		{ title: '退回时间', dataIndex: 'returnTime' },
		{ title: '退回理由', dataIndex: 'returnContent' },
		{
			title: '操作',
			dataIndex: 'action',
			width: 50,
			render: (_, record) => <Link onClick={() => handleJump(record)}>处理</Link>,
		},
	];

	return (
		<Page pageHead={{ title: '我的退回', subtitle: '被下一环节退回的任务清单' }}>
			<div className="myReturn">
				<div className="pageSearch">
					<TableSearch
						form={form}
						itemData={[
							{ type: 'Input', name: 'plaintiffs', label: '申请人' },
							{ type: 'Input', name: 'defendants', label: '被申请人' },
							{ type: 'RangePicker', name: 'returnTime', label: '退回时间' },
							{ type: 'Input', name: 'caseNo', label: '调解案号' },
							{ type: 'Input', name: 'addr', label: '纠纷发生地' },
						]}
						handleReset={() => handleSearch('reset')}
						handleSearch={() => handleSearch('search')}
					/>
				</div>
				<div className="pageTable myReturn-table">
					<TableView
						showHeader
						title="查询结果"
						columns={columns}
						dataSource={data.tableData}
						pagination={{
							current: search.page,
							pageSize: search.size,
							total: data.total,
							onChange: (page, pageSize) => handleSearch('changePage', [page, pageSize]),
						}}
						rowClassName={(record) => (record.id === data.tableActive ? 'tableRowActive' : '')}
					/>
				</div>
			</div>
		</Page>
	);
};

export default MyReturn;
